==> APMServices-SDK-iOS-1.5.3.tar.gz: APMServices-SDK-iOS-1.5.3/APMServices/Frameworks/APMServices.framework/Versions/A/Headers/UIAlertView+APMBlocks.h <==
//
//  UIAlertView+NSCookbook.m
//  SimpleAlertViewSampleApp
//
//  Copyright (c) 2013 NSCookbook. All rights reserved.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.

#import <objc/runtime.h>

@interface UIAlertView (APMBlocks)

- (void)showWithClickButton:(void(^)(NSInteger buttonIndex))onClickButton onDismiss:(void(^)(NSInteger buttonIndex))onDismiss;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle otherButtonTitles:(NSArray*) otherButtonTitles onClickButton:(void(^)( NSInteger buttonIndex))onClickButton onDismiss:(void(^)( NSInteger buttonIndex))onDismiss;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle validationButtonTitle:(NSString*) validationButtonTitle onClickButton:(void(^)(NSInteger buttonIndex))onClickButton onDismiss:(void(^)(NSInteger buttonIndex))onDismiss;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle validationButtonTitle:(NSString*) validationButtonTitle onClickButton:(void(^)(NSInteger buttonIndex))onClickButton;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle onClickButton:(void(^)(NSInteger buttonIndex))onClickButton;
+(void) showWithMessage:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle validationButtonTitle:(NSString*) validationButtonTitle onClickButton:(void(^)( NSInteger buttonIndex))onClickButton;
+(void) showWithMessage:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle onClickButton:(void(^)( NSInteger buttonIndex))onClickButton;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle;
+(void) showWithMessage:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle;

void import_UIAlertViewAPMBlocks ( );

@end

==> APMServices-SDK-iOS-2.1.9.tar.gz: APMServices-SDK-iOS-2.1.9/APMServices/Frameworks/APMServices.framework/Versions/A/Headers/UIAlertView+APMBlocks.h <==
//
//  UIAlertView+NSCookbook.m
//  SimpleAlertViewSampleApp
//
//  Copyright (c) 2013 NSCookbook. All rights reserved.
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.

#import <objc/runtime.h>

@interface UIAlertView (APMBlocks)

- (void)showWithClickButton:(void(^)(NSInteger buttonIndex))onClickButton;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle otherButtonTitles:(NSArray*) otherButtonTitles onClickButton:(void(^)( NSInteger buttonIndex))onClickButton;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle validationButtonTitle:(NSString*) validationButtonTitle onClickButton:(void(^)(NSInteger buttonIndex))onClickButton;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle onClickButton:(void(^)( NSInteger buttonIndex))onClickButton;
+(void) showWithMessage:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle validationButtonTitle:(NSString*) validationButtonTitle onClickButton:(void(^)( NSInteger buttonIndex))onClickButton;
+(void) showWithMessage:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle onClickButton:(void(^)( NSInteger buttonIndex))onClickButton;
+(void) showWithTitle:(NSString*) title message:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle;
+(void) showWithMessage:(NSString*) message cancelButtonTitle:(NSString *)cancelButtonTitle;

void import_UIAlertViewAPMBlocks ( void);

@end
